#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-DXGT5hmM8jS3TVtROXC2tb
key:                  wai-logger-2.5.0-DXGT5hmM8jS3TVtROXC2tb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  b0aa3e53f08bcb88a53d3ab413836d70
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-DXGT5hmM8jS3TVtROXC2tb
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 fast-logger-3.2.4-BcBZzOAKBToBJfOfnajTCu
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    network-3.1.4.0-9dONp0onFcbAlDBEoFNGkb
    wai-3.2.4-3XyCh5m71lWJYF48VLLZUp

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

